'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _babylon = require('babylon');

var _s2sUtils = require('s2s-utils');

var _flowFaker = require('flow-faker');

const INITIAL_STATE = 'initialState';

exports.default = () => {
  return {
    inherits: _s2sUtils.inheritsOpts,
    name: 's2s-initial-state-creater',
    visitor: {
      Program(programPath, state) {
        const { opts: { from } } = state;
        programPath.traverse({
          VariableDeclarator(nodePath) {
            const idPath = nodePath.get('id');

            if (idPath.node.name !== INITIAL_STATE) {
              return;
            }

            const { line, column } = nodePath.get('loc').get('start').node;
            const flowInfo = (0, _flowFaker.flowFakerSync)(from, {
              row: line,
              column: column + 1
            });

            const newAST = (0, _babylon.parseExpression)(JSON.stringify(flowInfo), {
              plugins: ['flow']
            });

            nodePath.get('init').replaceWith(newAST);
          }
        });
      }
    }
  };
};